@@ -6,55 +6,43 @@ class TFMProtocol(asyncio.Protocol):
 		self.buffer = bytearray()
 		self.client = conn.client
 		self.connection = conn
-		self.buffer_length = 0
-		self.length_bytes = 0
 		self.length = 0
-		self.read_length = False
-
-	def connection_made(self, transport):
-		self.connection.open = True
-		self.client.dispatch('connection_made', self.connection)
 
 	def data_received(self, data):
-		self.buffer_length += len(data)
 		self.buffer.extend(data)
 
-		while self.buffer_length > 0:
-			while self.buffer_length > 0 and not self.read_length:
-				self.buffer_length -= 1
-				byte = self.buffer.pop(0)
-				self.length |= (byte & 127) << (self.length_bytes * 7)
-				self.length_bytes += 1
+		while len(self.buffer) > self.length:
+			if self.length == 0:
+				for i in range(5):
+					byte = self.buffer.pop(0)
+					self.length |= (byte & 127) << (i * 7)
 
-				if byte & 128 == 128 and self.length_bytes < 5:
-					continue
+					if not byte & 0x80:
+						break
+				else:
+					raise Exception("wtf")
 
-				self.read_length = True
-
-			if self.read_length and self.buffer_length >= self.length:
+			if len(self.buffer) >= self.length:
 				self.client.data_received(self.buffer[:self.length], self.connection)
 				del self.buffer[:self.length]
-				self.buffer_length -= self.length
-
-				self.length_bytes = 0
 				self.length = 0
-				self.read_length = False
 
-			else:
-				break
+	def connection_made(self, transport):
+		# :desc: Called when a connection has been successfully made with the server.
+		# :param connection: :class:`Connection` the connection that has been made.
+		self.connection.open = True
+		self.client.dispatch('connection_made', self.connection)
 
 	def connection_lost(self, exc):
 		self.connection.open = False
 
 		if exc is not None:
-			future = self.client.dispatch('connection_error', self.connection, exc)
-			if future is not None:
-				# This future is a wrapper for _run_event, which returns True if the event
-				# ran successfully, False otherwise.
-				# If it returns False, it already handled the auto_restart.
-				if not asyncio.ensure_future(future):
-					return
+			# :desc: Called when a connection has been lost due to an error.
+			# :param connection: :class:`Connection` the connection that has been lost.
+			# :param exception: :class:`Exception` the error which occurred.
+			self.client.dispatch('connection_error', self.connection, exc)
 
+		if self.connection.name == "main":
 			if self.client.auto_restart:
 				self.client.loop.create_task(self.client.restart_soon())
 			else:
@@ -94,6 +82,9 @@ class Connection:
 		:param packet: :class:`aiotfm.Packet` the packet to send.
 		:param cipher: :class:`bool` whether or not the packet should be ciphered before sending it.
 		"""
+		if not self.open:
+			return
+
 		if cipher:
 			packet.xor_cipher(self.client.keys.msg, self.fingerprint)
 
@@ -110,4 +101,4 @@ class Connection:
 	def abort(self):
 		"""Abort the connection."""
 		self.transport.abort()
-		self.close()
\ No newline at end of file
+		self.close()
