@@ -9,6 +9,8 @@ class Packet:
 	Parameters
 	----------
 	buffer: Optional[:class:`bytes`]
+		The packet's buffer. The :class:`Packet` will be read-only if given.
+		If ``None`` is provided instead the :class:`Packet` will be in write-only mode.
 
 	Attributes
 	----------
@@ -26,10 +28,6 @@ class Packet:
 		self.buffer = buffer
 		self.pos = 0
 
-		self.exported = False
-		self.bytes = None
-		self._fp = 0
-
 	def __repr__(self):
 		return '<Packet {!r}>'.format(bytes(self))
 
@@ -39,18 +37,20 @@ class Packet:
 	@classmethod
 	def new(cls, c, cc=None):
 		"""Create a new instance of Packet initialized by two bytes: c and cc."""
-		msg = cls()
 		if isinstance(c, (tuple, list)):
 			c, cc = c
-		if cc is None:
-			return msg.write16(c)
-		return msg.write8(c).write8(cc)
+		elif cc is None:
+			return cls().write16(c)
 
-	def copy(self, pos=False):
+		return cls().write8(c).write8(cc)
+
+	def copy(self, copy_pos=False):
 		"""Returns a copy of the Packet"""
-		p = Packet(self.buffer.copy())
-		if pos:
+		p = Packet()
+		if copy_pos:
 			p.pos = self.pos
+
+		p.buffer = self.buffer.copy()
 		return p
 
 	def readBytes(self, nbr=1):
@@ -139,33 +139,21 @@ class Packet:
 
 	def export(self, fp=0):
 		"""Generates the header then converts the whole packet to bytes and returns it."""
-		if self.exported and self._fp == fp:
-			return self.bytes
-
 		m = Packet()
 		size = len(self.buffer)
 		size_type = size >> 7
 		while size_type != 0:
-			m.write8(size & 127 | 128)
+			m.write8(size & 0x7f | 0x80)
 			size = size_type
 			size_type >>= 7
-		m.write8(size & 127)
+		m.write8(size & 0x7f)
 		m.write8(fp)
 
-		self.bytes = bytes(m.buffer + self.buffer)
-		self.exported = True
-		self._fp = fp
-
-		return self.bytes
+		return bytes(m.buffer + self.buffer)
 
 	def xor_cipher(self, key, fp):
 		"""Cipher the packet with the XOR algorithm."""
-		fp += 1
-		ccc = self.readBytes(2)
-		tmp = bytearray(
-			(byte ^ key[(fp + i) % 20]) & 0xff for i, byte in enumerate(self.buffer[2:])
-		)
-		self.buffer = ccc + tmp
+		self.buffer[2:] = (byte ^ key[i % 20] for i, byte in enumerate(self.buffer[2:], fp + 1))
 		return self
 
 	def cipher(self, key):
@@ -175,17 +163,17 @@ class Packet:
 		if len(key) < 4:
 			raise XXTEAInvalidKeys(str(key))
 
-		ccc = self.read16()
+		header = self.buffer[:2]
 		length = len(self.buffer) - 2
 		if length % 4 > 0:
 			pad = 4 - length % 4
 			self.buffer.extend(bytes(pad))
 			length += pad
 
-		chunks = struct.unpack(f'>{length//4}I', self.readBytes(length))
+		chunks = struct.unpack(f'>{length//4}I', self.buffer[2:])
 		chunks = xxtea_encode(list(chunks), len(chunks), key)
 
-		packet = Packet.new(ccc).write16(len(chunks))
+		packet = Packet(header).write16(len(chunks))
 		packet.writeBytes(struct.pack(f'>{len(chunks)}I', *chunks))
 
 		self.buffer = packet.buffer
